@@ -784,13 +784,13 @@ listCtryNlData <- function(ctryCodes=NULL, nlPeriods=NULL, nlTypes=NULL, source=
 #' listCtryNlRasters()
 #' 
 #' #list all rasters available for KEN
-#' listCtryNlData(ctryCodes = "KEN")
+#' listCtryNlRasters(ctryCodes = "KEN")
 #' 
 #' #list all VIIRS rasters available for ECU
-#' listCtryNlData(ctryCodes = "ECU", nlTypes = "VIIRS")
+#' listCtryNlRasters(ctryCodes = "ECU", nlTypes = "VIIRS")
 #' 
 #' #list available OLS rasters for KEN and RWA in 2012 & 2013
-#' listCtryNlData(ctryCodes = c("KEN","RWA"), nlPeriods = c("2012", "2013"), nlTypes = "OLS")
+#' listCtryNlRasters(ctryCodes = c("KEN","RWA"), nlPeriods = c("2012", "2013"), nlTypes = "OLS")
 #'
 #' @export
 listCtryNlRasters <- function(ctryCodes=NULL, nlPeriods=NULL, nlTypes=NULL, source="local")
@@ -800,7 +800,7 @@ listCtryNlRasters <- function(ctryCodes=NULL, nlPeriods=NULL, nlTypes=NULL, sour
   nlPeriod <- NULL #appease CRAN note for global variables
   
   #get a list of country data files present
-  rasterList <- list.files(getNlDir("dirRasterOutput"), pattern = ".tif")
+  rasterList <- list.files(getNlDir("dirRasterOutput"), pattern = ".tif$")
 
   if(length(rasterList) == 0)
     return(NULL)
